# Wealthsimple-API-Python
A Python wrapper for the Wealthsimple Trade API.  
This wrapper is based off of Sean Sullivan's wrapper here, https://github.com/seansullivan44/Wealthsimple-Trade-Python, with additional features and functionality.  
Unofficial documentation for the Wealthsimple Trade API can be found here, https://github.com/MarkGalloway/wealthsimple-trade/blob/master/API.md, however, some of the
documentation is outdated. I found that the easiest way to explore the different API endpoints and expected payloads was by using Chrome DevTools to check requests as
you interact with the Wealthsimple Trade platform through your browser.

## Features

## Installation

## Getting Started

## Examples


